# [![Eryx](https://github.com/ImShyMike/Eryx/blob/main/assets/eryx_small.png)][pypi_url]
[![Build Status](https://github.com/ImShyMike/Eryx/actions/workflows/python-package.yml/badge.svg)](https://github.com/ImShyMike/Eryx/actions/workflows/python-package.yml)
[![License](https://img.shields.io/pypi/l/Eryx)](https://github.com/ImShyMike/Eryx/blob/main/LICENSE)
[![PyPI](https://img.shields.io/pypi/v/Eryx)][pypi_url]
[![Python Version](https://img.shields.io/pypi/pyversions/Eryx)][pypi_url]
[![PyPI - Wheel](https://img.shields.io/pypi/wheel/Eryx)][pypi_url]

[pypi_url]: https://pypi.org/project/Eryx

## What is Eryx?
 Eryx is a decently fast simple dynamically typed programming language similar to javascript/python.

## Installation
 To install the latest stable release, just install it from PyPI using:
```sh
pip install eryx
```
If you want to install the latest beta version head over to the [releases](https://github.com/ImShyMike/Eryx/releases) page, download the desired `.whl` file and install it using:
```sh
pip install Eryx-(version)-py3-none-any.whl
```

## Usage
The CLI can be executed by running one of the following commands after installing:
```sh
eryx
```
or
```sh
python -m eryx
```

The list of subcommands is:
* **repl**: Start the [REPL](https://wikipedia.org/wiki/REPL)
* **run**: Run an Eryx file
* **playground**: Start the web playground
* **test**: Run the test suite

## Documentation
Coming soon...

## Thanks
A huge thanks to [tylerlaceby](https://www.youtube.com/@tylerlaceby) for his ["Build a Custom Scripting Language In Typescript"](https://www.youtube.com/playlist?list=PL_2VhOvlMk4UHGqYCLWc6GO8FaPl8fQTh) playlist.

## License
This project is licensed under the [MIT License](LICENSE).
